V1AppointmentsApi class

Native Terminoperationen der V1-Fassade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppointments(DateTime from, DateTime to, {String username = '', String? query, int page = 0, int? perPage}) Future<RestApiResponse>
Ruft Termine aus einem bestimmten Zeitraum ab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchAppointmentsCreateException(String id, DateTime exceptionFrom, DateTime from, DateTime to, {String title = '', String place = '', String description = '', String owner = '', ISODuration remindBefore = const ISODuration(year: 0), DateTime? remindAt, bool wholeDay = false, bool group = false, List<String>? attendeesUserNames, List<String>? attendeesAddresses, List<String>? attendeesEmails, String notificationComment = '', bool notifyAllAttendees = false, bool isSerial = false, bool public = false, bool extern = false, int? type, int? occupancy, String rrule = ''}) Future<RestApiResponse>
This request allows to create Termin series exception
patchAppointmentsRemoveFromSeries(String id, DateTime date) Future<RestApiResponse>
This request allows to remove date from Termin series
patchAppointmentsUpdateAppointment(String id, DateTime from, DateTime to, {String title = '', String place = '', String description = '', String owner = '', ISODuration? remindBefore, DateTime? remindAt, bool wholeDay = false, bool group = false, List<String>? attendeesUserNames, List<String>? attendeesAddresses, List<String>? attendeesEmails, String notificationComment = '', bool notifyAllAttendees = false, bool isSerial = false, bool public = false, bool extern = false, int? type, int? occupancy, String rrule = ''}) Future<RestApiResponse>
This request allows to edit an appointment
postAppointments(DateTime from, DateTime to, {String title = '', String place = '', String description = '', String owner = '', ISODuration? remindBefore, DateTime? remindAt, bool wholeDay = false, bool group = false, List<String>? attendeesUserNames, List<String>? attendeesAddresses, List<String>? attendeesEmails, String notificationComment = '', bool notifyAllAttendees = false, bool isSerial = false, bool public = false, bool extern = false, int? type, int? occupancy, String rrule = ''}) Future<RestApiResponse>
Erstellt einen neuen Termin im Kalender
postAppointmentsInvitation(String id, String action, bool deleteAppointment) Future<RestApiResponse>
This request allows to reply to appointment invitation
postAppointmentsNextFreeDate(DateTime from, DateTime to, DateTime searchArea, List<String> users) Future<RestApiResponse>
This request allows to find next free date with given duration
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited