V1FoldersApi class

Native Ordneroperationen der V1-Fassade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteFolders(String path, {bool notEmpty = false}) Future<RestApiResponse>
Löscht einen Ordner
getFolderByOid(String oid, {bool reverseOrder = false, int page = 0, int? perPage, String query = ''}) Future<RestApiResponse>
Ruft Ordner-Inhalte über die Objekt-ID (OID) ab
getFolderByPath(String path, {bool reverseOrder = false, int page = 0, int? perPage, String query = ''}) Future<RestApiResponse>
Ruft Ordner-Inhalte über den Ordner-Pfad ab
getFolderByType(String folderType, {bool reverseOrder = false, int page = 0, int? perPage, String query = ''}) Future<RestApiResponse>
Ruft Ordner-Inhalte nach Ordner-Typ ab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchFoldersAdd(RestApiDOCUframeFolderType folderType, String folderId, List<String> documentOids, {String className = ''}) Future<RestApiResponse>
Fügt Dokumente zu einem Ordner hinzu
patchFoldersCopyDocuments(RestApiDOCUframeFolderType destinationFolderSourceType, String destinationFolderId, List<String> documentOids, {RestApiDOCUframeFolderType? sourceFolderSourceType, String? sourceFolderId, bool cut = true}) Future<RestApiResponse>
Kopiert oder verschiebt Dokumente zwischen Ordnern
patchFoldersRemoveDocuments(RestApiDOCUframeFolderType folderType, String folderId, List<String> documentOids, {String className = '', bool moveToTrashBin = true, dynamic deep = false}) Future<RestApiResponse>
Entfernt Dokumente aus einem Ordner
patchFoldersRename(String oid, String newName) Future<RestApiResponse>
Benennt einen Ordner um
postFolders(String folderName, String parentFolder, {RestApiDOCUframeFolderType parentFolderSourceType = RestApiDOCUframeFolderType.path}) Future<RestApiResponse>
Erstellt einen Unterordner
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited