V1MessagesApi class

Native Operationen für interne Nachrichten der V1-Fassade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchMessage(String oid, List<String> toUsers, String text, {String name = '', String description = '', bool addToIncomingFolder = true, String originalOid = '', String uuid = '', String serialization = '', String rightsControlKey = ''}) Future<RestApiResponse>
Bearbeitet eine Entwurfs-Nachricht
patchMessageSend(String oid, List<String> toUsers, String text, {String name = '', String description = '', bool addToIncomingFolder = true, String originalOid = '', String uuid = '', String serialization = '', String rightsControlKey = ''}) Future<RestApiResponse>
Bearbeitet und sendet eine Nachricht direkt
postMessage(List<String> toUsers, String text, {String name = '', String description = '', bool addToIncomingFolder = true, String originalOid = '', String uuid = '', String serialization = '', String rightsControlKey = '', String actions = ''}) Future<RestApiResponse>
Erstellt eine Nachricht als Entwurf
postMessageSend(List<String> toUsers, String text, {String name = '', String description = '', bool addToIncomingFolder = true, String originalOid = '', String uuid = '', String serialization = '', String rightsControlKey = '', String actions = ''}) Future<RestApiResponse>
Erstellt und sendet eine Nachricht direkt
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited