V1ModelsApi class
Native Modell-, Struktur- und Wörterbuch-Operationen der V1-Fassade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getExtModelIndexes(
{String classes = '', String rightsControlKey = ''}) → Future< RestApiResponse> - Ruft Datenbank-Index-Informationen ab
-
getExtModelML(
{List< String> ? headerClasses, List<String> ? bodyClasses, bool skipMembers = false}) → Future<RestApiResponse> - Ruft Machine Learning Modell-Daten ab
-
getExtModelStructure(
{String classes = '', String baseClasses = '', bool skipMembers = false, String rightsControlKey = ''}) → Future< RestApiResponse> - Ruft erweiterte Modell-Strukturinformationen ab
-
getModelDict(
String dict, {String langID = '', String rightsControlKey = ''}) → Future< RestApiResponse> - Ruft Wörterbuch-Daten aus dem Modell ab
-
getModelStructure(
{String classes = '', String baseClasses = '', bool skipMembers = false, String rightsControlKey = ''}) → Future< RestApiResponse> - Ruft die Modell-Struktur der Datenbank ab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited