V1ObjectsApi class

Native Objektoperationen der V1-Fassade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteObject(String objectOid, {String actions = '', bool moveToRecycler = false}) Future<RestApiResponse>
Löscht ein Objekt aus der Datenbank
getIncidentTree(String oid, {int deepLevel = -1, String serialization = '', String rightsControlKey = ''}) Future<RestApiResponse>
Ruft die Hierarchie von Aktionen/Vorgängen ab
getLockObject(String id) Future<RestApiObjectLockResponse>
Ruft den Sperrstatus eines Objekts ab.
getObject(String objectOid, {String className = '', String serialization = ''}) Future<RestApiResponse>
Ruft Objektdaten anhand der Objekt-ID ab
getObjects(String className, {String query = '', int page = 0, int? perPage, String serialization = '', String actions = '', String rightsControlKey = ''}) Future<RestApiResponse>
Ruft eine Liste von Objekten einer bestimmten Klasse ab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchObject(String objectOid, String body, {int storeMode = 0, int storeSecurityPolice = 0, String serialization = '', String actions = '', String rightsControlKey = ''}) Future<RestApiResponse>
Bearbeitet ein bestehendes Objekt
patchObjects(String className, {String query = '', String body = '', int storeMode = 0, int storeSecurityPolice = 0, String serialization = '', String actions = '', String rightsControlKey = ''}) Future<RestApiResponse>
Bearbeitet mehrere Objekte einer Klasse gleichzeitig
postAction(String className, {String query = '', int page = 0, int? perPage, String serialization = '', String actions = '', String rightsControlKey = ''}) Future<RestApiResponse>
Führt eine Aktion auf Objekten einer bestimmten Klasse aus
postObject(String className, String body, {int storeMode = 0, String serialization = '', String actions = '', String rightsControlKey = ''}) Future<RestApiResponse>
Erstellt ein neues Objekt in der Datenbank
setObjectSecurity(String oid, Map<String, int> userObjectSecurity, {bool replace = false}) Future<RestApiResponse>
Setzt die Objekt-Sicherheitseinstellungen für ein Dokument/Objekt
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited