V1PersonalApi class
Native persönliche V1-Operationen für den angemeldeten Benutzer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPersonalMyTasks(
) → Future< RestApiResponse> - Ruft persönliche Aufgaben des aktuellen Benutzers ab
-
getPersonalUnreadDocuments(
) → Future< RestApiResponse> - Ruft ungelesene Dokumente des aktuellen Benutzers ab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patchPersonalEmptyRecycleBin(
) → Future< RestApiResponse> - Leert den Papierkorb des aktuellen Benutzers
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited