V1ServiceApi class

Native Service-, Lizenz- und Versionsoperationen der V1-Fassade.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkService() → Future<RestApiCheckServiceResponse>
Überprüft den aktuellen Webservice über '/CheckService'
checkServiceWithUri(Uri requestUri) → Future<RestApiCheckServiceResponse>
Prüft einen DOCUframe-Service über eine absolute URI.
getVersionInfo() → Future<RestApiVersionInfoResponse>
Ruft Versionsinformationen des Servers ab
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postLicenseRelease(List<String> appnames, String sessionId) → Future<RestApiResponse>
Gibt Lizenzen für Anwendungen frei
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited