V1SettingsApi class
Native Benutzer-Einstellungsoperationen der V1-Fassade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getUserSystemSettings(
{String eventMacroName = ''}) → Future< RestApiUserSystemSettingsResponse> - Ruft Benutzer-Systemeinstellungen ab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postUserSettings(
String key, Map< String, dynamic> data) → Future<RestApiResponse> - Speichert Benutzereinstellungen auf dem Server
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited