V1XSyncApi class

Native Synchronisationsoperationen unter v1/xSync.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSyncClassInfo(String appName) Future<RestApiResponse>
Ruft Synchronisations-Klassen-Informationen für eine Anwendung ab.
getSyncObjectsOfClass(String appName, String className, {List<RestApiSyncContainer> nextContainers = const [], int? maxRecords}) Future<RestApiSyncClassResponse>
Ruft Synchronisations-Objekte einer bestimmten Klasse ab.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited