V2FileApi class
Native V2-Dateioperationen.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String oid, {int? page, bool? usePdf, int? attachItem, int? zipItem, int? maxSize}) → Future< RestApiFileResponse> -
Lädt eine Datei über
GET v2/file/{oid}herunter. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited