HttpRequestException class

Exception für HTTP-Request-Fehler

Wird geworfen, wenn eine HTTP-Anfrage einen Fehlercode zurückgibt und der Webservice daher nicht erreicht werden konnte.

Diese Exception tritt auf bei:

  • Netzwerkproblemen
  • Server nicht erreichbar
  • HTTP-Statuscodes != 200
  • Timeout-Problemen
Implemented types

Constructors

HttpRequestException(String message, String statusCode, {String? reasonPhrase = ""})
Erstellt eine neue HttpRequestException

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Beschreibende Fehlernachricht
getter/setter pair
reasonPhrase String?
Die Statusnachricht aus der HTTP-Antwort
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode String
Der tatsächliche Statuscode aus der HTTP-Antwort
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited