Invalid2FATokenException class

Exception für ungültigen 2FA-Token

Wird geworfen, wenn der Webservice den Fehlercode 342 zurückgibt, was bedeutet, dass ein erforderlicher 2FA-Token ungültig ist.

Diese Exception tritt auf bei:

  • Ungültigem 2FA-Token

Für alle Fehlercodes siehe: https://docs.gsd.pl/restapi/errorCodes/errorCodes/

Inheritance

Constructors

Invalid2FATokenException([String message = "", String statusCode = "", String statusMessage = ""])
Erstellt eine neue Invalid2FATokenException

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Beschreibende Fehlernachricht über den Webservice-Fehler
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode String
Der interne Statuscode vom Webservice
getter/setter pairinherited
statusMessage String
Die detaillierte Statusnachricht vom Webservice
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
String-Darstellung der Exception im Format "StatusCode: StatusMessage"
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited