Require2FALoginException class

Inheritance

Constructors

Require2FALoginException([String message = "", String statusCode = "", String statusMessage = ""])

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Beschreibende Fehlernachricht über den Webservice-Fehler
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode String
Der interne Statuscode vom Webservice
getter/setter pairinherited
statusMessage String
Die detaillierte Statusnachricht vom Webservice
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
String-Darstellung der Exception im Format "StatusCode: StatusMessage"
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited