RestApi2FASecretResponse class
Antwort-Klasse für 2FA (Zwei-Faktor-Authentifizierung) Secret-Anfragen
Diese Klasse verarbeitet die Antwort des Servers bei Anfragen bezüglich der 2FA-Konfiguration und des Status des Benutzers.
- Inheritance
-
- Object
- RestApiResponse
- RestApi2FASecretResponse
Constructors
- RestApi2FASecretResponse(Response _httpResponse)
- Erstellt eine neue RestApi2FASecretResponse-Instanz
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpResponse → Response
-
Getter für die rohe HTTP-Antwort
no setterinherited
- internalStatus → String
-
Getter für den internen Statuscode
no setterinherited
- isActivated ↔ bool
-
Gibt an, ob 2FA für den Benutzer aktiviert ist
getter/setter pair
- isConfirmed ↔ bool
-
Gibt an, ob die 2FA-Konfiguration bestätigt wurde
getter/setter pair
- isOk → bool
-
Getter für den Erfolgsstatus
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusMessage → String
-
Getter für die Statusnachricht
no setterinherited
- twoFaStatus ↔ RestApi2FAStatus
-
Numerischer Status der Zwei-Faktor-Authentifizierung
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited