RestApiDOCUframeModule class

Repräsentiert ein Modul im REST-API-Service

Diese Klasse kapselt Informationen über ein verfügbares Modul in einer REST-API-Datenbank, einschließlich Name und Version.

Module erweitern die Funktionalität der REST-API und haben spezifische Versionsnummern für Kompatibilitätsprüfungen.

Wird verwendet für:

  • Feature-Verfügbarkeit-Checks
  • Versions-Kompatibilität zwischen Client und Server
  • Funktions-spezifische API-Aufrufe

Constructors

RestApiDOCUframeModule(String name, String version)
Erstellt eine neue RestApiModule-Instanz

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Name des Moduls
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
Version des Moduls
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited