RestApiFileResponse class

Response-Klasse für Datei-Download-Anfragen

Spezialisierte Response-Klasse für den Download von Dateien über die REST-API. Im Gegensatz zu normalen API-Responses enthält diese Klasse die rohen Datei-Bytes anstatt JSON-Daten.

Verwendung:

  • Datei-Downloads über /v1/file/{oid}
  • Binärdaten (Bilder, Dokumente, etc.)
  • Direct File Access ohne JSON-Wrapper

Constructors

RestApiFileResponse(Response _httpResponse)
Erstellt eine RestApiFileResponse-Instanz

Properties

hashCode int
The hash code for this object.
no setterinherited
httpResponse → Response
Getter für die HTTP-Response
no setter
isOk bool
Getter für den Erfolgsstatus
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited