RestApiResponse class

Basisklasse für alle REST-API-Antworten

Diese Klasse verarbeitet HTTP-Antworten von der REST-API und extrahiert Statusinformationen. Sie wirft entsprechende Exceptions basierend auf dem internen Statuscode der API-Antwort.

Unterstützte Statuscodes:

  • 0: Erfolg
  • 201: Session ungültig
  • 204: Token oder Session fehlt
  • 302: Falsche Benutzerdaten
  • 306/101: Lizenzprobleme
  • Andere: Allgemeine Webservice-Fehler
Implementers

Constructors

RestApiResponse(Response _httpResponse)
Erstellt eine RestApiResponse-Instanz basierend auf einer HTTP-Antwort

Properties

hashCode int
The hash code for this object.
no setterinherited
httpResponse → Response
Getter für die rohe HTTP-Antwort
no setter
internalStatus String
Getter für den internen Statuscode
no setter
isOk bool
Getter für den Erfolgsstatus
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String
Getter für die Statusnachricht
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited