RestApiSyncClassResponse class
Response-Klasse für Synchronisations-API-Aufrufe
Diese Klasse verarbeitet die Antworten von Synchronisations-Endpunkten, die Container-basierte Daten mit Klassen zurückgeben.
- Inheritance
-
- Object
- RestApiResponse
- RestApiSyncClassResponse
Constructors
- RestApiSyncClassResponse(Response _httpResponse)
- Erstellt eine RestApiSyncClassResponse-Instanz
Properties
-
allContainers
↔ List<
String> -
Liste aller verfügbaren Container-IDs
getter/setter pair
-
containers
↔ Map<
String, RestApiSyncContainer> -
Map der Container-Daten
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpResponse → Response
-
Getter für die rohe HTTP-Antwort
no setterinherited
- internalStatus → String
-
Getter für den internen Statuscode
no setterinherited
- isOk → bool
-
Getter für den Erfolgsstatus
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusMessage → String
-
Getter für die Statusnachricht
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited