SecureHttpClientWeb class

Sicherer HTTP-Client für Web-Plattformen

Erweitert den Standard-BrowserClient um Sicherheitsvalidierung:

  • Verhindert unverschlüsselte HTTP-Verbindungen (außer explizit erlaubt)
  • Validiert URLs vor jeder Anfrage
  • Wirft SecurityException bei unsicheren Verbindungen
  • Unterliegt Browser-Sicherheitsrichtlinien (CORS, Mixed Content, etc.)

Verwendet die nativen Browser-APIs für HTTP-Kommunikation.

Constructors

SecureHttpClientWeb({bool allowSslError = false})
Erstellt einen neuen SecureHttpClientWeb

Properties

allowSslError → bool
Ob unsichere HTTP-Verbindungen erlaubt sind
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withCredentials ↔ bool
Whether to send credentials such as cookies or authorization headers for cross-site requests.
getter/setter pairinherited

Methods

close() → void
Closes the client.
inherited
delete(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) → Future<Response>
DELETE-Anfrage mit URL-Validierung
get(Uri url, {Map<String, String>? headers}) → Future<Response>
GET-Anfrage mit URL-Validierung
HEAD-Anfrage mit URL-Validierung
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) → Future<Response>
PATCH-Anfrage mit URL-Validierung
post(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) → Future<Response>
POST-Anfrage mit URL-Validierung
put(Uri url, {Map<String, String>? headers, Object? body, Encoding? encoding}) → Future<Response>
PUT-Anfrage mit URL-Validierung
read(Uri url, {Map<String, String>? headers}) → Future<String>
Liest URL-Inhalt als String mit URL-Validierung
readBytes(Uri url, {Map<String, String>? headers}) → Future<Uint8List>
Liest URL-Inhalt als Bytes mit URL-Validierung
send(BaseRequest request) → Future<StreamedResponse>
Sendet eine HTTP-Anfrage mit URL-Validierung
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited