ApiHttpMethod enum
HTTP-Methode für einen RawApi-Request oder eine interne ApiRequest.
Bildet die von der DOCUframe-API unterstützten Methoden ab. Der Enum-Name entspricht (in Großschreibung) direkt der HTTP-Methode und wird intern zur Transport-Konstruktion verwendet.
Values
- get → const ApiHttpMethod
-
GET-Anfrage zum Abrufen von Daten.
- post → const ApiHttpMethod
-
POST-Anfrage zum Erstellen neuer Ressourcen.
- put → const ApiHttpMethod
-
PUT-Anfrage zum vollständigen Ersetzen einer Ressource.
- patch → const ApiHttpMethod
-
PATCH-Anfrage zum teilweisen Aktualisieren einer Ressource.
- delete → const ApiHttpMethod
-
DELETE-Anfrage zum Löschen einer Ressource.
- head → const ApiHttpMethod
-
HEAD-Anfrage zum Abrufen von Headern ohne Response-Body.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ApiHttpMethod> - A constant List of the values in this enum, in order of their declaration.