DocuframeRuntimeSettings class
Unveränderlicher Abzug der kontrolliert veränderbaren Runtime-Werte.
Properties
-
additionalAppNames
→ List<
String> -
final
-
appNames
→ List<
String> -
final
- bufferFlushDelayMs → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBufferSize → int
-
final
- multiRequest → bool
-
final
- perPageCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useBase64UrlParameter → bool
-
final
- useFolderPathEncoding → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited