DocuframeV2Api class
Öffentliche Gruppen der nativen V2-API.
Alle Gruppen verwenden denselben Runtime und Sessionzustand wie V1 und
laufen niemals über RawApi, customRequest oder den Legacy-Manager.
Properties
- file ↔ V2FileApi
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- model ↔ V2ModelApi
-
getter/setter pair
- objectData ↔ V2ObjectDataApi
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system ↔ V2SystemApi
-
getter/setter pair
- view ↔ V2ViewApi
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited