V1DocumentsApi class
Native Dokument-, Datei- und Uploadoperationen der V1-Fassade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDocumentPaths(
String oid, {bool extended = false}) → Future< RestApiResponse> - Ruft Dokumentpfade für ein Objekt ab
-
getFile(
String oid) → Future< RestApiFileResponse> - Lädt eine Datei anhand ihrer Objekt-ID herunter
-
getPreview(
String objectOid, String parameters, {int page = 0, bool keepRatio = true}) → Future< Uint8List?> - Generiert eine Vorschau-Darstellung eines Objekts
-
getUploadFile(
String uploadID) → Future< RestApiResponse> - Ruft Informationen über eine hochgeladene Datei ab, einschließlich Größe und MD5-Hash
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putDocsHistory(
List< String> ids, {String action = 'add', String className = ''}) → Future<RestApiResponse> - Verwaltet die Objekthistorie des Benutzers
-
putDocsNotNew(
List< String> ids) → Future<RestApiResponse> - Markiert Dokumente als nicht mehr neu
-
putDocsRead(
List< String> ids, {bool read = true}) → Future<RestApiResponse> - Markiert Dokumente als gelesen oder ungelesen
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
RestApiUploadFile file, {String replaceOID = '', bool patch = true, bool fetchToObject = true}) → Future< RestApiResponse> - Lädt eine Datei auf den Server hoch
-
uploadFileWithController(
RestApiUploadFile file, {String replaceOID = '', bool patch = true, bool fetchToObject = true, dynamic out}) → Future< RestAPIFileUploadController> - Lädt eine Datei mit Upload-Controller hoch
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited