V1IntegrationsApi class
Native Makro-, Druck- und Telefonie-Integrationen der V1-Fassade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCalls(
{String query = '', int page = 0, int? perPage, String serialization = '', String rightsControlKey = ''}) → Future< RestApiResponse> - Ruft Anruflisten und Telefonie-Daten ab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postExecuteInterfaceMacro(
String macroName, {Map< String, dynamic> ? body}) → Future<Response> - Führt ein Schnittstellenmakro auf dem Server aus
-
postPrintMacrosExecute(
String text, {String addressOid = '', String addressNrOid = '', String contactPersonOid = '', String incidentOid = '', String objectOid = ''}) → Future< RestApiResponse> - Führt Druck-Makros aus und ersetzt Platzhalter mit Objektdaten
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited