V1TimeRecordingApi class
Native Personalzeiterfassungs-Operationen (PZE) der V1-Fassade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPZEWorkingTimeAccounts(
{String serialization = '', String? employeeOid, DateTime? from, DateTime? to}) → Future< RestApiResponse> - Ruft Arbeitszeitkonten für einen Zeitraum ab
-
getPZEWorkingTimeKeys(
{String serialization = ''}) → Future< RestApiResponse> - Ruft verfügbare Arbeitszeitschlüssel für die PZE ab
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postPZEClockIn(
{String? employeeoid, String? key}) → Future< RestApiResponse> - Startet die Zeiterfassung (Einstempeln) für einen Mitarbeiter
-
postPZEClockOut(
{String? employeeoid}) → Future< RestApiResponse> - Beendet die Zeiterfassung (Ausstempeln) für einen Mitarbeiter
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited