RestApi2FAStatus enum
Enum für die verschiedenen 2FA (Zwei-Faktor-Authentifizierung) Status-Werte
Diese Enumeration definiert die möglichen Zustände der Zwei-Faktor-Authentifizierung im REST-API-System. Jeder Status hat eine eindeutige numerische ID.
Values
- na → const RestApi2FAStatus
-
Nicht verfügbar - 2FA ist nicht verfügbar oder nicht unterstützt
const RestApi2FAStatus(0) - deactivated → const RestApi2FAStatus
-
Deaktiviert - 2FA ist nicht verfügbar
const RestApi2FAStatus(1) - optional → const RestApi2FAStatus
-
Optional - 2FA ist verfügbar und kann vom Benutzer aktiviert werden
const RestApi2FAStatus(2) - forced → const RestApi2FAStatus
-
Erzwungen - 2FA ist vom System vorgeschrieben und muss verwendet werden
const RestApi2FAStatus(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Die numerische ID des 2FA-Status
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RestApi2FAStatus> - A constant List of the values in this enum, in order of their declaration.