RestApiCheckServiceResponse class
Response-Klasse für Service-Status-Überprüfungen
Erweitert die Basis-RestApiResponse um service-spezifische Informationen:
- Anwendungsname und -version
- Verfügbare Datenbanken und deren Module
- Webservice-Versionsinformationen
Diese Klasse wird verwendet, um den Status und die Verfügbarkeit des REST-API-Services zu überprüfen, bevor eine Verbindung hergestellt wird.
- Inheritance
-
- Object
- RestApiResponse
- RestApiCheckServiceResponse
Constructors
- RestApiCheckServiceResponse(Response _httpResponse)
- Erstellt eine RestApiCheckServiceResponse-Instanz
Properties
- applicationName ↔ String
-
Name der Anwendung vom Server
getter/setter pair
- applicationVersion ↔ String
-
Version der Anwendung vom Server
getter/setter pair
-
databases
↔ List<
RestApiDOCUframeDatabase> -
Liste der verfügbaren Datenbanken und deren Module
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpResponse → Response
-
Getter für die rohe HTTP-Antwort
no setterinherited
- internalStatus → String
-
Getter für den internen Statuscode
no setterinherited
- isOk → bool
-
Getter für den Erfolgsstatus
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusMessage → String
-
Getter für die Statusnachricht
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited