RestApiVersionInfoResponse class
Response-Klasse für Webservice-Versionsinformationen
Diese Klasse wird verwendet, um detaillierte Informationen über die Version des REST-API-Webservices und seiner Module zu erhalten.
Verwendung:
- Kompatibilitätsprüfungen zwischen Client und Server
- Feature-Verfügbarkeit basierend auf Versionen
- Update-Management und Migrations-Unterstützung
- Debugging und Support-Informationen
- Inheritance
-
- Object
- RestApiResponse
- RestApiVersionInfoResponse
Constructors
- RestApiVersionInfoResponse(Response _httpResponse)
- Erstellt eine RestApiVersionInfoResponse-Instanz
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpResponse → Response
-
Getter für die rohe HTTP-Antwort
no setterinherited
- internalStatus → String
-
Getter für den internen Statuscode
no setterinherited
- isOk → bool
-
Getter für den Erfolgsstatus
no setterinherited
-
modules
↔ List<
RestApiDOCUframeModule> -
Liste der verfügbaren Module mit Versionen
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceVersion ↔ String
-
Version des Webservices
getter/setter pair
- statusMessage → String
-
Getter für die Statusnachricht
no setterinherited
- structureChangeDate ↔ DateTime?
-
Datum der letzten Strukturänderung
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited